function subregions = region_partition(V,P)
%
%subregions = region_partition(V,P)
%
%Given a convex polygon represented as the k-by-2 matrix V, and a point set
%represented by the n-by-2 matrix P, returns a k-by-2 cell array 'subregions'
%whose (i,1) element contains the vertices of a subregion, and whose (i,2)
%element contains one element of the point set.  Each element of the first
%column of 'subregions' has the same area and is convex.
%
%example:
%load USA.mat
%subregions = region_partition(V,P);
%draw_regions(subregions);

if size(P,1) == 1
    subregions{1,1} = V; subregions{1,2} = P;
else
    subregions = regionp(V,P);
    if size(subregions,1) == 2
        V1 = subregions{1,1}; P1 = subregions{1,2};
        V2 = subregions{2,1}; P2 = subregions{2,2};
        subregions1 = region_partition(V1,P1);
        subregions2 = region_partition(V2,P2);
        subregions = [subregions1; subregions2];
    else
        V1 = subregions{1,1}; P1 = subregions{1,2};
        V2 = subregions{2,1}; P2 = subregions{2,2};
        V3 = subregions{2,1}; P3 = subregions{2,2};
        subregions1 = region_partition(V1,P1);
        subregions2 = region_partition(V2,P2);
        subregions3 = region_partition(V3,P3);
        subregions = [subregions1; subregions2;subregions3];
    end
end